%define name fftw
%define version 2.1.5
%define release 1

Name: %{name}
Summary: fast fourier transform library
Version: %{version}
Release: %{release}
License: GPL
Icon: fftw-logo-thumb.gif
Group: Libraries
Prefix: %{_prefix}
BuildRoot: %{_tmppath}/%{name}-%{version}-buildroot

Source: ftp://ftp.fftw.org/pub/fftw/fftw-%{version}.tar.bz2
URL: http://www.fftw.org/

%description
FFTW is a collection of fast C routines for computing the Discrete Fourier
Transform in one or more dimensions.  It includes complex, real, and
parallel transforms, and can handle arbitrary array sizes efficiently.
This RPM package includes both the double- and single-precision FFTW
uniprocessor and threads libraries.  (The single-precision files have
an "s" prefix.)

%package devel
Summary: headers, libraries, & docs for FFTW fast fourier transform library
Group: Development/Libraries
Prefix: %{prefix}
Requires: fftw = %{version}-%{release}

%description devel
This package contains the additional header files, documentation, and
libraries you need to develop programs using the FFTW fast fourier
transform library.

%prep

# We will be compiling two copies of FFTW, one for double precision and
# one for single precision.  During the build process, these copies
# will be stored in fftw-%{version}/double and fftw-%{version}/single

# Unpack the tar archive, first (-c) creating a fftw-%{version}
# directory and then unpacking in there.

%setup -c
# Now, rename the unpacked FFTW directory to "double":
mv ${RPM_PACKAGE_NAME}-${RPM_PACKAGE_VERSION} double
# Second, make a copy of this directory in "single":
cp -r double single

%build

# Configure and build the double and single precision versions.
# Notes:
#  (1) We install into ${RPM_BUILD_ROOT}, which is set either
#      by the BuildRoot option above or by --buildroot at build-time.
#      This allows you to build the RPM without blowing away your existing
#      FFTW installation, and even without being root.
#  (2) The double-precision version is installed with the normal library
#      names, while the single-precision version is installed with an "s"
#      prefix.

cd double

%ifarch i386 i586 i686
#CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix="${RPM_BUILD_ROOT}%{prefix}" --enable-shared --enable-i386-hacks --enable-threads
%configure --enable-shared --enable-i386-hacks --enable-threads

%else
#CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix="${RPM_BUILD_ROOT}%{prefix}" --enable-shared --enable-threads
%configure --enable-shared --enable-threads

%endif
make
cd ../single
#CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix="${RPM_BUILD_ROOT}%{prefix}" --enable-shared --enable-type-prefix --enable-threads --enable-float
%configure --enable-shared --enable-type-prefix --enable-threads --enable-float
make -j 2

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
cd double
make DESTDIR="$RPM_BUILD_ROOT" install
cd ../single
make DESTDIR="$RPM_BUILD_ROOT" install
#bzip2 -9 $RPM_BUILD_ROOT%{_infodir}/*

%clean

rm -rf ${RPM_BUILD_ROOT}

%post
# Force ${RPM_INSTALL_PREFIX}/lib to be in /etc/ld.so.conf?
# No...that would make it impossible to completely uninstall reliably.
# Instead, warn the user fix a broken /etc/ld.so.conf manually:
if test -z `grep ${RPM_INSTALL_PREFIX}/lib /etc/ld.so.conf`; then
     echo "warning: ${RPM_INSTALL_PREFIX}/lib is not in /etc/ld.so.conf" 1>&2
     echo "         You should add it and then run ldconfig." 1>&2
fi

# run ldconfig to update the runtime linker database with the new libraries
# (make sure /sbin is in the $PATH)
PATH="/sbin:$PATH" ldconfig

%postun
# after uninstall, run ldconfig to remove the libs from the linker database
PATH="/sbin:$PATH" ldconfig

%files
%defattr (-,root,root)
%{_libdir}/libfftw.so.2.0.7
%{_libdir}/libfftw_threads.so.2.0.7
%{_libdir}/librfftw.so.2.0.7
%{_libdir}/librfftw_threads.so.2.0.7
%{_libdir}/libsfftw.so.2.0.7
%{_libdir}/libsfftw_threads.so.2.0.7
%{_libdir}/libsrfftw.so.2.0.7
%{_libdir}/libsrfftw_threads.so.2.0.7
%{_libdir}/libfftw.so.2
%{_libdir}/libfftw_threads.so.2
%{_libdir}/librfftw.so.2
%{_libdir}/librfftw_threads.so.2
%{_libdir}/libsfftw.so.2
%{_libdir}/libsfftw_threads.so.2
%{_libdir}/libsrfftw.so.2
%{_libdir}/libsrfftw_threads.so.2

%files devel
%defattr (-,root,root)
%{_includedir}/fftw.h
%{_includedir}/fftw_threads.h
%{_includedir}/rfftw.h
%{_includedir}/rfftw_threads.h
%{_includedir}/sfftw.h
%{_includedir}/sfftw_threads.h
%{_includedir}/srfftw.h
%{_includedir}/srfftw_threads.h
%{_infodir}/fftw.info.*
%{_infodir}/fftw.info-1.*
%{_infodir}/fftw.info-2.*
%{_infodir}/fftw.info-3.*
%{_infodir}/fftw.info-4.*
%{_infodir}/fftw.info-5.*
%{_libdir}/libfftw.a
%{_libdir}/libfftw.la
%{_libdir}/libfftw.so
%{_libdir}/libfftw_threads.a
%{_libdir}/libfftw_threads.la
%{_libdir}/libfftw_threads.so
%{_libdir}/librfftw.a
%{_libdir}/librfftw.la
%{_libdir}/librfftw.so
%{_libdir}/librfftw_threads.a
%{_libdir}/librfftw_threads.la
%{_libdir}/librfftw_threads.so
%{_libdir}/libsfftw.a
%{_libdir}/libsfftw.la
%{_libdir}/libsfftw.so
%{_libdir}/libsfftw_threads.a
%{_libdir}/libsfftw_threads.la
%{_libdir}/libsfftw_threads.so
%{_libdir}/libsrfftw.a
%{_libdir}/libsrfftw.la
%{_libdir}/libsrfftw.so
%{_libdir}/libsrfftw_threads.a
%{_libdir}/libsrfftw_threads.la
%{_libdir}/libsrfftw_threads.so

%changelog
* Fri Oct 10 2003 Peter Hanecak <hanecak@megaloman.sk> 2.1.5-1
- update to 2.1.5
- s/Copyright/License

* Mon Aug 28 2000 Peter Hanecak <hanecak@megaloman.sk>
- spec improvements

* Sat Feb 26 2000 Peter Hanecak <hanecak@megaloman.sk>
- '--enable-i386-hacks' even for i586 and i686 architectures

* Tue Jan 25 2000 Lenny Cartier <lenny@mandrakesoft.com>
- updated, installs in /usr instead of /usr/local by Dara Hazeghi
  <dara@pacbell.net>

* Thu Dec 16 1999 Lenny Cartier <lenny@mandrakesoft.com>
- new in contribs
- bz2 archive 
- add defattr
